@@ -24,6 +24,7 @@ from pm4py.statistics.traces.log import case_statistics
 from pm4py.statistics.variants.log import get as variants_statistics
 from pm4py.util import exec_utils
 from pm4py.algo.clustering.trace_attribute_driven.parameters import Parameters
+from pm4py.util import variants_util
 
 
 def apply_trace_attributes(log, list_of_values, parameters=None):
@@ -94,9 +95,8 @@ def sublog2varlist(log, freq_thres, num):
 
     # union set ensure the ordered union will be satisfied
     filtered_var_list = filtered_var_list_1 + filtered_var_list_2
-    str_var_list = []
-    for str in filtered_var_list:
-        str_var_list.extend([str.split(',')])
+    str_var_list = [variants_util.get_activities_from_variant(v) for v in filtered_var_list]
+
     return str_var_list
 
 
@@ -124,9 +124,8 @@ def sublog_percent(log, upper_percent, parameters=None):
     df_w_count = df.iloc[len(num_list_lower):len(num_list), :]
     # get correspond var_list
     filtered_var_list = df_w_count['variant'].values.tolist()
-    str_var_list = []
-    for str in filtered_var_list:
-        str_var_list.extend([str.split(',')])
+    str_var_list = [variants_util.get_activities_from_variant(v) for v in filtered_var_list]
+
     return df_w_count, str_var_list
 
 
@@ -154,9 +153,8 @@ def sublog_percent2actlist(log, upper_percent, parameters=None):
     df_w_count = df.iloc[len(num_list_lower):len(num_list), :]
     # get correspond var_list
     filtered_var_list = df_w_count['variant'].values.tolist()
-    str_var_list = []
-    for str in filtered_var_list:
-        str_var_list.extend(str.split(','))
+    str_var_list = [variants_util.get_activities_from_variant(v) for v in filtered_var_list]
+
     return df_w_count, str_var_list
 
 
