@@ -38,6 +38,7 @@ from enum import Enum
 import heapq
 import numpy as np
 from copy import copy
+from pm4py.util import variants_util
 
 
 class Parameters(Enum):
@@ -161,15 +162,8 @@ def apply_from_variant(variant, petri_net, initial_marking, final_marking, param
     """
     if parameters is None:
         parameters = {}
-    activity_key = DEFAULT_NAME_KEY if parameters is None or PARAMETER_CONSTANT_ACTIVITY_KEY not in parameters else \
-        parameters[
-            pm4pyutil.constants.PARAMETER_CONSTANT_ACTIVITY_KEY]
-    trace = log_implementation.Trace()
-    variant_delimiter = exec_utils.get_param_value(Parameters.PARAMETER_VARIANT_DELIMITER, parameters,
-                                                   pm4pyutil.constants.DEFAULT_VARIANT_SEP)
-    variant_split = variant.split(variant_delimiter) if type(variant) is str else variant
-    for i in range(len(variant_split)):
-        trace.append(log_implementation.Event({activity_key: variant_split[i]}))
+    trace = variants_util.variant_to_trace(variant, parameters=parameters)
+
     return apply(trace, petri_net, initial_marking, final_marking, parameters=parameters)
 
 
