@@ -1,3 +1,19 @@
+'''
+    This file is part of PM4Py (More Info: https://pm4py.fit.fraunhofer.de).
+
+    PM4Py is free software: you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
+
+    PM4Py is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
+'''
 from pm4py.objects.bpmn.bpmn_graph import BPMN
 from pm4py.util import constants
 import uuid
@@ -76,10 +92,16 @@ def parse_element(bpmn_graph, counts, curr_el, parents, incoming_dict, outgoing_
         nodes_dict[id] = node
     elif tag.endswith("incoming"):
         if node is not None:
-            incoming_dict[curr_el.text] = node
+            incoming_dict[curr_el.text.strip()] = node
     elif tag.endswith("outgoing"):
         if node is not None:
-            outgoing_dict[curr_el.text] = node
+            outgoing_dict[curr_el.text.strip()] = node
+    elif tag.endswith("sequenceflow"):
+        seq_flow_id = curr_el.get("id")
+        source_ref = curr_el.get("sourceRef")
+        target_ref = curr_el.get("targetRef")
+        incoming_dict[seq_flow_id] = nodes_dict[target_ref]
+        outgoing_dict[seq_flow_id] = nodes_dict[source_ref]
     elif tag.endswith("waypoint"):
         if flow is not None:
             x = float(curr_el.get("x"))
