@@ -1,3 +1,19 @@
+'''
+    This file is part of PM4Py (More Info: https://pm4py.fit.fraunhofer.de).
+
+    PM4Py is free software: you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
+
+    PM4Py is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
+'''
 from pm4py.util.business_hours import BusinessHours
 from pm4py.objects.log.util import sorting
 from pm4py.util import constants
@@ -60,15 +76,21 @@ def to_interval(log, parameters=None):
                 if transition.lower() == "start":
                     if activity not in activities_start:
                         activities_start[activity] = list()
-                    activities_start[activity].append(timestamp)
+                    activities_start[activity].append(event)
                 elif transition.lower() == "complete":
+                    start_event = None
                     start_timestamp = event[timestamp_key]
                     if activity in activities_start and len(activities_start[activity]) > 0:
-                        start_timestamp = activities_start[activity].pop(0)
+                        start_event = activities_start[activity].pop(0)
+                        start_timestamp = start_event[timestamp_key]
                     new_event = Event()
                     for attr in event:
                         if not attr == timestamp_key and not attr == transition_key:
                             new_event[attr] = event[attr]
+                    if start_event is not None:
+                        for attr in start_event:
+                            if not attr == timestamp_key and not attr == transition_key:
+                                new_event["@@startevent_" + attr] = start_event[attr]
                     new_event[start_timestamp_key] = start_timestamp
                     new_event[timestamp_key] = timestamp
                     new_event["@@duration"] = (timestamp - start_timestamp).total_seconds()
