@@ -21,6 +21,7 @@ from pm4py.util.constants import CASE_CONCEPT_NAME
 from pm4py.util import exec_utils, constants, pandas_utils
 from enum import Enum
 import pandas as pd
+from pm4py.util import variants_util
 
 
 class Parameters(Enum):
@@ -192,7 +193,11 @@ def get_variants_df(df, parameters=None):
     case_id_glue = exec_utils.get_param_value(Parameters.CASE_ID_KEY, parameters, CASE_CONCEPT_NAME)
     activity_key = exec_utils.get_param_value(Parameters.ACTIVITY_KEY, parameters, xes.DEFAULT_NAME_KEY)
 
-    new_df = df.groupby(case_id_glue)[activity_key].agg(lambda col: ",".join(pd.Series.to_list(col))).to_frame()
+    if variants_util.VARIANT_SPECIFICATION == variants_util.VariantsSpecifications.STRING:
+        new_df = df.groupby(case_id_glue)[activity_key].agg(lambda col: ",".join(pd.Series.to_list(col))).to_frame()
+    elif variants_util.VARIANT_SPECIFICATION == variants_util.VariantsSpecifications.LIST:
+        new_df = df.groupby(case_id_glue)[activity_key].agg(lambda col: tuple(pd.Series.to_list(col))).to_frame()
+
     new_cols = list(new_df.columns)
     new_df = new_df.rename(columns={new_cols[0]: "variant"})
 
@@ -227,7 +232,11 @@ def get_variants_df_with_case_duration(df, parameters=None):
 
     grouped_df = df[[case_id_glue, timestamp_key, activity_key]].groupby(df[case_id_glue])
 
-    df1 = grouped_df[activity_key].agg(lambda col: ",".join(pd.Series.to_list(col))).to_frame()
+    df1 = None
+    if variants_util.VARIANT_SPECIFICATION == variants_util.VariantsSpecifications.STRING:
+        df1 = grouped_df[activity_key].agg(lambda col: ",".join(pd.Series.to_list(col))).to_frame()
+    elif variants_util.VARIANT_SPECIFICATION == variants_util.VariantsSpecifications.LIST:
+        df1 = grouped_df[activity_key].agg(lambda col: tuple(pd.Series.to_list(col))).to_frame()
     new_cols = list(df1.columns)
     df1 = df1.rename(columns={new_cols[0]: "variant"})
 
